#[non_exhaustive]pub struct StartCallAnalyticsStreamTranscriptionOutput {Show 20 fields
pub request_id: Option<String>,
pub language_code: Option<CallAnalyticsLanguageCode>,
pub media_sample_rate_hertz: Option<i32>,
pub media_encoding: Option<MediaEncoding>,
pub vocabulary_name: Option<String>,
pub session_id: Option<String>,
pub call_analytics_transcript_result_stream: EventReceiver<CallAnalyticsTranscriptResultStream, CallAnalyticsTranscriptResultStreamError>,
pub vocabulary_filter_name: Option<String>,
pub vocabulary_filter_method: Option<VocabularyFilterMethod>,
pub language_model_name: Option<String>,
pub identify_language: bool,
pub language_options: Option<String>,
pub preferred_language: Option<CallAnalyticsLanguageCode>,
pub vocabulary_names: Option<String>,
pub vocabulary_filter_names: Option<String>,
pub enable_partial_results_stabilization: bool,
pub partial_results_stability: Option<PartialResultsStability>,
pub content_identification_type: Option<ContentIdentificationType>,
pub content_redaction_type: Option<ContentRedactionType>,
pub pii_entity_types: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_id: Option<String>Provides the identifier for your real-time Call Analytics request.
language_code: Option<CallAnalyticsLanguageCode>Provides the language code that you specified in your Call Analytics request.
media_sample_rate_hertz: Option<i32>Provides the sample rate that you specified in your Call Analytics request.
media_encoding: Option<MediaEncoding>Provides the media encoding you specified in your Call Analytics request.
vocabulary_name: Option<String>Provides the name of the custom vocabulary that you specified in your Call Analytics request.
session_id: Option<String>Provides the identifier for your Call Analytics transcription session.
call_analytics_transcript_result_stream: EventReceiver<CallAnalyticsTranscriptResultStream, CallAnalyticsTranscriptResultStreamError>Provides detailed information about your real-time Call Analytics session.
vocabulary_filter_name: Option<String>Provides the name of the custom vocabulary filter that you specified in your Call Analytics request.
vocabulary_filter_method: Option<VocabularyFilterMethod>Provides the vocabulary filtering method used in your Call Analytics transcription.
language_model_name: Option<String>Provides the name of the custom language model that you specified in your Call Analytics request.
identify_language: boolShows whether automatic language identification was enabled for your Call Analytics transcription.
language_options: Option<String>Provides the language codes that you specified in your Call Analytics request.
preferred_language: Option<CallAnalyticsLanguageCode>Provides the preferred language that you specified in your Call Analytics request.
vocabulary_names: Option<String>Provides the names of the custom vocabularies that you specified in your Call Analytics request.
vocabulary_filter_names: Option<String>Provides the names of the custom vocabulary filters that you specified in your Call Analytics request.
enable_partial_results_stabilization: boolShows whether partial results stabilization was enabled for your Call Analytics transcription.
partial_results_stability: Option<PartialResultsStability>Provides the stabilization level used for your transcription.
content_identification_type: Option<ContentIdentificationType>Shows whether content identification was enabled for your Call Analytics transcription.
content_redaction_type: Option<ContentRedactionType>Shows whether content redaction was enabled for your Call Analytics transcription.
pii_entity_types: Option<String>Lists the PII entity types you specified in your Call Analytics request.
Implementations
Sourceimpl StartCallAnalyticsStreamTranscriptionOutput
impl StartCallAnalyticsStreamTranscriptionOutput
Sourcepub fn request_id(&self) -> Option<&str>
pub fn request_id(&self) -> Option<&str>
Provides the identifier for your real-time Call Analytics request.
Sourcepub fn language_code(&self) -> Option<&CallAnalyticsLanguageCode>
pub fn language_code(&self) -> Option<&CallAnalyticsLanguageCode>
Provides the language code that you specified in your Call Analytics request.
Sourcepub fn media_sample_rate_hertz(&self) -> Option<i32>
pub fn media_sample_rate_hertz(&self) -> Option<i32>
Provides the sample rate that you specified in your Call Analytics request.
Sourcepub fn media_encoding(&self) -> Option<&MediaEncoding>
pub fn media_encoding(&self) -> Option<&MediaEncoding>
Provides the media encoding you specified in your Call Analytics request.
Sourcepub fn vocabulary_name(&self) -> Option<&str>
pub fn vocabulary_name(&self) -> Option<&str>
Provides the name of the custom vocabulary that you specified in your Call Analytics request.
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
Provides the identifier for your Call Analytics transcription session.
Sourcepub fn call_analytics_transcript_result_stream(
&self,
) -> &EventReceiver<CallAnalyticsTranscriptResultStream, CallAnalyticsTranscriptResultStreamError>
pub fn call_analytics_transcript_result_stream( &self, ) -> &EventReceiver<CallAnalyticsTranscriptResultStream, CallAnalyticsTranscriptResultStreamError>
Provides detailed information about your real-time Call Analytics session.
Sourcepub fn vocabulary_filter_name(&self) -> Option<&str>
pub fn vocabulary_filter_name(&self) -> Option<&str>
Provides the name of the custom vocabulary filter that you specified in your Call Analytics request.
Sourcepub fn vocabulary_filter_method(&self) -> Option<&VocabularyFilterMethod>
pub fn vocabulary_filter_method(&self) -> Option<&VocabularyFilterMethod>
Provides the vocabulary filtering method used in your Call Analytics transcription.
Sourcepub fn language_model_name(&self) -> Option<&str>
pub fn language_model_name(&self) -> Option<&str>
Provides the name of the custom language model that you specified in your Call Analytics request.
Sourcepub fn identify_language(&self) -> bool
pub fn identify_language(&self) -> bool
Shows whether automatic language identification was enabled for your Call Analytics transcription.
Sourcepub fn language_options(&self) -> Option<&str>
pub fn language_options(&self) -> Option<&str>
Provides the language codes that you specified in your Call Analytics request.
Sourcepub fn preferred_language(&self) -> Option<&CallAnalyticsLanguageCode>
pub fn preferred_language(&self) -> Option<&CallAnalyticsLanguageCode>
Provides the preferred language that you specified in your Call Analytics request.
Sourcepub fn vocabulary_names(&self) -> Option<&str>
pub fn vocabulary_names(&self) -> Option<&str>
Provides the names of the custom vocabularies that you specified in your Call Analytics request.
Sourcepub fn vocabulary_filter_names(&self) -> Option<&str>
pub fn vocabulary_filter_names(&self) -> Option<&str>
Provides the names of the custom vocabulary filters that you specified in your Call Analytics request.
Sourcepub fn enable_partial_results_stabilization(&self) -> bool
pub fn enable_partial_results_stabilization(&self) -> bool
Shows whether partial results stabilization was enabled for your Call Analytics transcription.
Sourcepub fn partial_results_stability(&self) -> Option<&PartialResultsStability>
pub fn partial_results_stability(&self) -> Option<&PartialResultsStability>
Provides the stabilization level used for your transcription.
Sourcepub fn content_identification_type(&self) -> Option<&ContentIdentificationType>
pub fn content_identification_type(&self) -> Option<&ContentIdentificationType>
Shows whether content identification was enabled for your Call Analytics transcription.
Sourcepub fn content_redaction_type(&self) -> Option<&ContentRedactionType>
pub fn content_redaction_type(&self) -> Option<&ContentRedactionType>
Shows whether content redaction was enabled for your Call Analytics transcription.
Sourcepub fn pii_entity_types(&self) -> Option<&str>
pub fn pii_entity_types(&self) -> Option<&str>
Lists the PII entity types you specified in your Call Analytics request.
Sourceimpl StartCallAnalyticsStreamTranscriptionOutput
impl StartCallAnalyticsStreamTranscriptionOutput
Sourcepub fn deserialize(
deserializer: &mut dyn ShapeDeserializer,
) -> Result<Self, SerdeError>
pub fn deserialize( deserializer: &mut dyn ShapeDeserializer, ) -> Result<Self, SerdeError>
Deserializes this structure from a [ShapeDeserializer].
Sourceimpl StartCallAnalyticsStreamTranscriptionOutput
impl StartCallAnalyticsStreamTranscriptionOutput
Sourcepub fn deserialize_with_response(
deserializer: &mut dyn ShapeDeserializer,
headers: &Headers,
_status: u16,
_body: &[u8],
) -> Result<Self, SerdeError>
pub fn deserialize_with_response( deserializer: &mut dyn ShapeDeserializer, headers: &Headers, _status: u16, _body: &[u8], ) -> Result<Self, SerdeError>
Deserializes this structure from a body deserializer and HTTP response headers. Header-bound members are read directly from headers, avoiding runtime member iteration overhead. Body members are read via the deserializer.
Sourceimpl StartCallAnalyticsStreamTranscriptionOutput
impl StartCallAnalyticsStreamTranscriptionOutput
Sourcepub fn builder() -> StartCallAnalyticsStreamTranscriptionOutputBuilder
pub fn builder() -> StartCallAnalyticsStreamTranscriptionOutputBuilder
Creates a new builder-style object to manufacture StartCallAnalyticsStreamTranscriptionOutput.