#[non_exhaustive]pub struct StartMedicalScribeStreamOutput {
pub session_id: Option<String>,
pub request_id: Option<String>,
pub language_code: Option<MedicalScribeLanguageCode>,
pub media_sample_rate_hertz: Option<i32>,
pub media_encoding: Option<MedicalScribeMediaEncoding>,
pub result_stream: EventReceiver<MedicalScribeResultStream, MedicalScribeResultStreamError>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: Option<String>The identifier (in UUID format) for your streaming session.
If you already started streaming, this is same ID as the one you specified in your initial StartMedicalScribeStreamRequest.
request_id: Option<String>The unique identifier for your streaming request.
language_code: Option<MedicalScribeLanguageCode>The Language Code that you specified in your request. Same as provided in the StartMedicalScribeStreamRequest.
media_sample_rate_hertz: Option<i32>The sample rate (in hertz) that you specified in your request. Same as provided in the StartMedicalScribeStreamRequest
media_encoding: Option<MedicalScribeMediaEncoding>The Media Encoding you specified in your request. Same as provided in the StartMedicalScribeStreamRequest
result_stream: EventReceiver<MedicalScribeResultStream, MedicalScribeResultStreamError>The result stream where you will receive the output events.
Implementations
Sourceimpl StartMedicalScribeStreamOutput
impl StartMedicalScribeStreamOutput
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
The identifier (in UUID format) for your streaming session.
If you already started streaming, this is same ID as the one you specified in your initial StartMedicalScribeStreamRequest.
Sourcepub fn request_id(&self) -> Option<&str>
pub fn request_id(&self) -> Option<&str>
The unique identifier for your streaming request.
Sourcepub fn language_code(&self) -> Option<&MedicalScribeLanguageCode>
pub fn language_code(&self) -> Option<&MedicalScribeLanguageCode>
The Language Code that you specified in your request. Same as provided in the StartMedicalScribeStreamRequest.
Sourcepub fn media_sample_rate_hertz(&self) -> Option<i32>
pub fn media_sample_rate_hertz(&self) -> Option<i32>
The sample rate (in hertz) that you specified in your request. Same as provided in the StartMedicalScribeStreamRequest
Sourcepub fn media_encoding(&self) -> Option<&MedicalScribeMediaEncoding>
pub fn media_encoding(&self) -> Option<&MedicalScribeMediaEncoding>
The Media Encoding you specified in your request. Same as provided in the StartMedicalScribeStreamRequest
Sourcepub fn result_stream(
&self,
) -> &EventReceiver<MedicalScribeResultStream, MedicalScribeResultStreamError>
pub fn result_stream( &self, ) -> &EventReceiver<MedicalScribeResultStream, MedicalScribeResultStreamError>
The result stream where you will receive the output events.
Sourceimpl StartMedicalScribeStreamOutput
impl StartMedicalScribeStreamOutput
Sourcepub fn deserialize(
deserializer: &mut dyn ShapeDeserializer,
) -> Result<Self, SerdeError>
pub fn deserialize( deserializer: &mut dyn ShapeDeserializer, ) -> Result<Self, SerdeError>
Deserializes this structure from a [ShapeDeserializer].
Sourceimpl StartMedicalScribeStreamOutput
impl StartMedicalScribeStreamOutput
Sourcepub fn deserialize_with_response(
deserializer: &mut dyn ShapeDeserializer,
headers: &Headers,
_status: u16,
_body: &[u8],
) -> Result<Self, SerdeError>
pub fn deserialize_with_response( deserializer: &mut dyn ShapeDeserializer, headers: &Headers, _status: u16, _body: &[u8], ) -> Result<Self, SerdeError>
Deserializes this structure from a body deserializer and HTTP response headers. Header-bound members are read directly from headers, avoiding runtime member iteration overhead. Body members are read via the deserializer.
Sourceimpl StartMedicalScribeStreamOutput
impl StartMedicalScribeStreamOutput
Sourcepub fn builder() -> StartMedicalScribeStreamOutputBuilder
pub fn builder() -> StartMedicalScribeStreamOutputBuilder
Creates a new builder-style object to manufacture StartMedicalScribeStreamOutput.